==> angelspetrochem_0.5.11.zip: angelspetrochem_0.5.11/prototypes/items/petrochem-nitrogen.lua <==
data:extend(
{
--NITROGEN
{
    type = "fluid",
    name = "gas-nitrogen",
    icon = "__angelspetrochem__/graphics/icons/gas-nitrogen.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0, g = 0, b = 1},
    flow_color = {r = 0, g = 0, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ammonia",
    icon = "__angelspetrochem__/graphics/icons/gas-ammonia.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.05, g = 0.05, b = 1},
    flow_color = {r = 0.05, g = 0.05, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-nitrogen-monoxide",
    icon = "__angelspetrochem__/graphics/icons/gas-nitrogen-monoxide.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.1, g = 0.1, b = 1},
    flow_color = {r = 0.1, g = 0.1, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-nitrogen-dioxide",
    icon = "__angelspetrochem__/graphics/icons/gas-nitrogen-dioxide.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.15, g = 0.15, b = 1},
    flow_color = {r = 0.15, g = 0.15, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-dinitrogen-tetroxide",
    icon = "__angelspetrochem__/graphics/icons/gas-dinitrogen-tetroxide.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.2, g = 0.2, b = 1},
    flow_color = {r = 0.2, g = 0.2, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ammonium-chloride",
    icon = "__angelspetrochem__/graphics/icons/gas-ammonium-chloride.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.25, g = 0.25, b = 1},
    flow_color = {r = 0.25, g = 0.25, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-urea",
    icon = "__angelspetrochem__/graphics/icons/gas-urea.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.3, g = 0.3, b = 1},
    flow_color = {r = 0.3, g = 0.3, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-melamine",
    icon = "__angelspetrochem__/graphics/icons/gas-melamine.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.35, g = 0.35, b = 1},
    flow_color = {r = 0.35, g = 0.35, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "liquid-nitric-acid",
    icon = "__angelspetrochem__/graphics/icons/liquid-nitric-acid.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.4, g = 0.4, b = 0.1},
    flow_color = {r = 0.4, g = 0.4, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-monochloramine",
    icon = "__angelspetrochem__/graphics/icons/gas-monochloramine.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.45, g = 0.45, b = 1},
    flow_color = {r = 0.45, g = 0.45, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-hydrazine",
    icon = "__angelspetrochem__/graphics/icons/gas-hydrazine.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.5, g = 0.5, b = 1},
    flow_color = {r = 0.5, g = 0.5, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-methylamine",
    icon = "__angelspetrochem__/graphics/icons/gas-methylamine.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.55, g = 0.55, b = 0.1},
    flow_color = {r = 0.55, g = 0.55, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-dimethylamine",
    icon = "__angelspetrochem__/graphics/icons/gas-dimethylamine.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.6, g = 0.6, b = 1},
    flow_color = {r = 0.6, g = 0.6, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-dimethylhydrazine",
    icon = "__angelspetrochem__/graphics/icons/gas-dimethylhydrazine.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.65, g = 0.65, b = 1},
    flow_color = {r = 0.65, g = 0.65, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
}
)

==> angelspetrochem_0.7.6.zip: angelspetrochem_0.7.6/prototypes/items/petrochem-nitrogen.lua <==
data:extend(
{
--NITROGEN
{
    type = "fluid",
    name = "gas-nitrogen",
    icon = "__angelspetrochem__/graphics/icons/gas-nitrogen.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0, g = 0, b = 1},
    flow_color = {r = 0, g = 0, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ammonia",
    icon = "__angelspetrochem__/graphics/icons/gas-ammonia.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.05, g = 0.05, b = 1},
    flow_color = {r = 0.05, g = 0.05, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-nitrogen-monoxide",
    icon = "__angelspetrochem__/graphics/icons/gas-nitrogen-monoxide.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.1, g = 0.1, b = 1},
    flow_color = {r = 0.1, g = 0.1, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-nitrogen-dioxide",
    icon = "__angelspetrochem__/graphics/icons/gas-nitrogen-dioxide.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.15, g = 0.15, b = 1},
    flow_color = {r = 0.15, g = 0.15, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-dinitrogen-tetroxide",
    icon = "__angelspetrochem__/graphics/icons/gas-dinitrogen-tetroxide.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.2, g = 0.2, b = 1},
    flow_color = {r = 0.2, g = 0.2, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ammonium-chloride",
    icon = "__angelspetrochem__/graphics/icons/gas-ammonium-chloride.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.25, g = 0.25, b = 1},
    flow_color = {r = 0.25, g = 0.25, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-urea",
    icon = "__angelspetrochem__/graphics/icons/gas-urea.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.3, g = 0.3, b = 1},
    flow_color = {r = 0.3, g = 0.3, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-melamine",
    icon = "__angelspetrochem__/graphics/icons/gas-melamine.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.35, g = 0.35, b = 1},
    flow_color = {r = 0.35, g = 0.35, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "liquid-nitric-acid",
    icon = "__angelspetrochem__/graphics/icons/liquid-nitric-acid.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.4, g = 0.4, b = 0.1},
    flow_color = {r = 0.4, g = 0.4, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-monochloramine",
    icon = "__angelspetrochem__/graphics/icons/gas-monochloramine.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.45, g = 0.45, b = 1},
    flow_color = {r = 0.45, g = 0.45, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-hydrazine",
    icon = "__angelspetrochem__/graphics/icons/gas-hydrazine.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.5, g = 0.5, b = 1},
    flow_color = {r = 0.5, g = 0.5, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-methylamine",
    icon = "__angelspetrochem__/graphics/icons/gas-methylamine.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.55, g = 0.55, b = 0.1},
    flow_color = {r = 0.55, g = 0.55, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-dimethylamine",
    icon = "__angelspetrochem__/graphics/icons/gas-dimethylamine.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.6, g = 0.6, b = 1},
    flow_color = {r = 0.6, g = 0.6, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-dimethylhydrazine",
    icon = "__angelspetrochem__/graphics/icons/gas-dimethylhydrazine.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.65, g = 0.65, b = 1},
    flow_color = {r = 0.65, g = 0.65, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
}
)
